Updated helm charts for e-release
Still staging images, need to be switched to release image when release is made.
Issue-ID: NONRTRIC-622
Signed-off-by: BjornMagnussonXA <bjorn.magnusson@est.tech>
Change-Id: I6604221cf9da0be36fb504cc753ef92188ca1ad4
diff --git a/nonrtric/RECIPE_EXAMPLE/example_recipe.yaml b/nonrtric/RECIPE_EXAMPLE/example_recipe.yaml
index 24f3a8f..73de17e 100644
--- a/nonrtric/RECIPE_EXAMPLE/example_recipe.yaml
+++ b/nonrtric/RECIPE_EXAMPLE/example_recipe.yaml
@@ -22,14 +22,16 @@
# Here you can enable inclusion or exclusion of each component. A not installed component will not be installed.
nonrtric:
installPms: true
- installA1controller: false
- installA1simulator: false
+ installA1controller: true
+ installA1simulator: true
installControlpanel: true
- installEnrichmentservice: true
- installRappcatalogueservice: false
+ installInformationservice: true
+ installRappcatalogueservice: true
installNonrtricgateway: true
installKong: false
- installDmaapAdapterservice: true
+ installDmaapadapterservice: true
+ installDmaapmediatorservice: true
+ installHelmmanager: true
volume1:
# Set the size to 0 if you do not need the volume (if you are using Dynamic Volume Provisioning)
size: 2Gi
@@ -37,7 +39,10 @@
volume2:
# Set the size to 0 if you do not need the volume (if you are using Dynamic Volume Provisioning)
size: 2Gi
- storageClassName: ecs-storage
+ storageClassName: ics-storage
+ volume3:
+ size: 1Gi
+ storageClassName: helmmanager-storage
common:
releasePrefix: r3-dev-nonrtric
@@ -45,12 +50,13 @@
namespace:
nonrtric: nonrtric
ingressClassName: kong
-enrichmentservice:
- enrichmentservice:
- imagePullPolicy: IfNotPresent
+
+informationservice:
+ informationservice:
+ imagePullPolicy: Always
image:
registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
- name: 'nonrtric-enrichment-coordinator-service'
+ name: 'nonrtric-information-coordinator-service'
tag: 1.2.0
service:
allowHttp: true
@@ -67,19 +73,21 @@
initialDelaySeconds: 20
periodSeconds: 10
persistence:
- # Either refer to a volume created under the nonrtric by storageClassName. Then the claimed size should be the same.
- # The alternative use a dynamic volume provisioner in the cluster. Storage class can then be fon instance 'standard' or 'gluster-fs' (depeneds on which classes that are available)
+ # Either refer to a volume created under the nonrtric by storageClassName. Then the claimed size should be the same.
+ # The alternative use a dynamic volume provisioner in the cluster. Storage class can then be for instance 'standard' or 'gluster-fs' (depeneds on which classes that are available)
size: 2Gi
- storageClassName: ecs-storage
+ storageClassName: ics-storage
+ ingress:
+ enabled: true
# Need to check the external port Availability
policymanagementservice:
policymanagementservice:
- imagePullPolicy: IfNotPresent
+ imagePullPolicy: Always
image:
registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: nonrtric-policy-agent
- tag: 2.2.1
+ tag: 2.3.0
service:
allowHttp: true
httpName: http
@@ -95,20 +103,21 @@
initialDelaySeconds: 20
periodSeconds: 10
persistence:
- # Either refer to a volume created under the nonrtric by storageClassName. Then the claimed size should be the same.
- # The alternative use a dynamic volume provisioner in the cluster. Storage class can then be fon instance 'standard' or 'gluster-fs' (depeneds on which classes that are available)
+ # Either refer to a volume created under the nonrtric by storageClassName. Then the claimed size should be the same.
+ # The alternative use a dynamic volume provisioner in the cluster. Storage class can then be for instance 'standard' or 'gluster-fs' (depeneds on which classes that are available)
size: 2Gi
storageClassName: pms-storage
-
+ ingress:
+ enabled: true
# A1 Conttroller may take few more minutes to start. Increase the initialDelaySeconds in liveness to avoid container restart.
a1controller:
a1controller:
- imagePullPolicy: IfNotPresent
+ imagePullPolicy: Always
image:
- registry: 'nexus3.o-ran-sc.org:10002/o-ran-sc'
- name: nonrtric-a1-controller
- tag: 2.0.1
+ registry: 'nexus3.onap.org:10002/onap'
+ name: sdnc-image
+ tag: 2.1.6
replicaCount: 1
service:
allowHttp: true
@@ -128,11 +137,11 @@
a1simulator:
a1simulator:
name: a1-sim
- imagePullPolicy: IfNotPresent
+ imagePullPolicy: Always
image:
- registry: 'nexus3.o-ran-sc.org:10002/o-ran-sc'
+ registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: a1-simulator
- tag: 2.1.0
+ tag: 2.2.0
service:
allowHttp: true
httpName: http
@@ -159,11 +168,11 @@
controlpanel:
controlpanel:
- imagePullPolicy: IfNotPresent
+ imagePullPolicy: Always
image:
registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: nonrtric-controlpanel
- tag: 2.2.0
+ tag: 2.3.0
replicaCount: 1
service:
allowHttp: true
@@ -181,26 +190,24 @@
readiness:
initialDelaySeconds: 20
periodSeconds: 10
+ ingress:
+ enabled: false
- ingress:
- enabled: false
- ingress:
- enabled: false
rappcatalogueservice:
rappcatalogueservice:
- imagePullPolicy: IfNotPresent
+ imagePullPolicy: Always
image:
- registry: 'nexus3.o-ran-sc.org:10002/o-ran-sc'
+ registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: nonrtric-r-app-catalogue
- tag: 1.0.0
+ tag: 1.1.0
service:
allowHttp: true
httpName: http
internalPort1: 9085
- targetPort1: 8080
+ targetPort1: 8680
httpsName: https
internalPort2: 9086
- targetPort2: 8433
+ targetPort2: 8633
liveness:
initialDelaySeconds: 20
periodSeconds: 10
@@ -210,11 +217,11 @@
nonrtricgateway:
nonrtricgateway:
- imagePullPolicy: IfNotPresent
+ imagePullPolicy: Always
image:
registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: nonrtric-gateway
- tag: 1.0.0
+ tag: 1.1.0
service:
httpName: http
internalPort1: 9090
@@ -229,7 +236,7 @@
dmaapadapterservice:
dmaapadapterservice:
- imagePullPolicy: IfNotPresent
+ imagePullPolicy: Always
image:
registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: 'nonrtric-dmaap-adaptor'
@@ -248,3 +255,49 @@
readiness:
initialDelaySeconds: 20
periodSeconds: 10
+
+dmaapmediatorservice:
+ dmaapmediatorservice:
+ imagePullPolicy: IfNotPresent
+ image:
+ registry: "nexus3.o-ran-sc.org:10004/o-ran-sc"
+ name: "nonrtric-dmaap-mediator-producer"
+ tag: 1.0.0
+ service:
+ allowHttp: true
+ httpName: http
+ internalPort1: 8085
+ targetPort1: 8085
+ httpsName: https
+ internalPort2: 8185
+ targetPort2: 8185
+ liveness:
+ initialDelaySeconds: 20
+ periodSeconds: 10
+ readiness:
+ initialDelaySeconds: 20
+ periodSeconds: 10
+
+helmmanager:
+ helmmanager:
+ clusterRoleName: cluster-admin
+ imagePullPolicy: Always
+ image:
+ registry: "nexus3.o-ran-sc.org:10004/o-ran-sc"
+ name: "nonrtric-helm-manager"
+ tag: 1.1.0
+ service:
+ httpName: http
+ internalPort1: 8112
+ targetPort1: 8083
+ liveness:
+ initialDelaySeconds: 20
+ periodSeconds: 10
+ readiness:
+ initialDelaySeconds: 20
+ periodSeconds: 10
+ persistence:
+ # Either refer to a volume created under the nonrtric by storageClassName. Then the claimed size should be the same.
+ # The alternative use a dynamic volume provisioner in the cluster. Storage class can then be for instance 'standard' or 'gluster-fs' (depeneds on which classes that are available)
+ size: 1Gi
+ storageClassName: helmmanager-storage
\ No newline at end of file
diff --git a/nonrtric/data/prepare_data.sh b/nonrtric/data/prepare_data.sh
index d605efb..0181f6d 100755
--- a/nonrtric/data/prepare_data.sh
+++ b/nonrtric/data/prepare_data.sh
@@ -19,16 +19,16 @@
# This script is populating some data into nonrtric for demo/test purpose.
# First this script copies data/ folder into one of the rics, in below case a1-sim-osc-0.
-# Then from the ric, run populate_policy_data.sh and populate_enrichment_data.sh.
+# Then from the ric, run populate_policy_data.sh and populate_information_data.sh.
# populate_policy_data.sh creates policy-types, service, and policies.
-# populate_enrichment_data.sh creates EiProducer, EiType, and EiJob.
+# populate_information_data.sh creates EiProducer, EiType, and EiJob.
#
# Why we run the scripts in the ric, not from the host?
# Because a1-simulators(ric) are deployed in statefulset,
# they are not exposed to outside the k8s cluster.
# And we must create policy type into the ric first.
-# Similarly, the enrichmentservice is not exposed outside the k8s cluster,
-# hence the commands for populating enrichment data need to be run from within the cluster.
+# Similarly, the informationservice is not exposed outside the k8s cluster,
+# hence the commands for populating information data need to be run from within the cluster.
kubectl -n nonrtric cp run_in_k8s a1-sim-osc-0:/usr/src/app/
-kubectl -n nonrtric exec -it a1-sim-osc-0 -- bash -c 'cd run_in_k8s/ && ./populate_policy_data.sh && ./populate_enrichment_data.sh'
\ No newline at end of file
+kubectl -n nonrtric exec -it a1-sim-osc-0 -- bash -c 'cd run_in_k8s/ && ./populate_policy_data.sh && ./populate_information_data.sh'
\ No newline at end of file
diff --git a/nonrtric/data/run_in_k8s/testdata/ECS/EiJob.json b/nonrtric/data/run_in_k8s/testdata/ICS/EiJob.json
similarity index 100%
rename from nonrtric/data/run_in_k8s/testdata/ECS/EiJob.json
rename to nonrtric/data/run_in_k8s/testdata/ICS/EiJob.json
diff --git a/nonrtric/data/run_in_k8s/testdata/ECS/EiProducer.json b/nonrtric/data/run_in_k8s/testdata/ICS/EiProducer.json
similarity index 100%
rename from nonrtric/data/run_in_k8s/testdata/ECS/EiProducer.json
rename to nonrtric/data/run_in_k8s/testdata/ICS/EiProducer.json
diff --git a/nonrtric/data/run_in_k8s/testdata/ECS/EiType.json b/nonrtric/data/run_in_k8s/testdata/ICS/EiType.json
similarity index 100%
rename from nonrtric/data/run_in_k8s/testdata/ECS/EiType.json
rename to nonrtric/data/run_in_k8s/testdata/ICS/EiType.json
diff --git a/nonrtric/helm/a1controller/templates/deployment.yaml b/nonrtric/helm/a1controller/templates/deployment.yaml
index c5eb596..e21ce87 100644
--- a/nonrtric/helm/a1controller/templates/deployment.yaml
+++ b/nonrtric/helm/a1controller/templates/deployment.yaml
@@ -44,11 +44,6 @@
- name: {{ include "common.containername.a1controller" . }}
image: {{ .Values.a1controller.image.registry }}/{{ .Values.a1controller.image.name }}:{{ .Values.a1controller.image.tag }}
imagePullPolicy: {{ .Values.a1controller.imagePullPolicy }}
- env:
- - name: MYSQL_ROOT_PASSWORD
- value: openECOMP1.0
- - name: SDNC_CONFIG_DIR
- value: /opt/onap/sdnc/data/properties
command:
- /opt/onap/sdnc/bin/startODL.sh
ports:
@@ -56,6 +51,35 @@
protocol: TCP
- containerPort: {{ .Values.a1controller.service.targetPort2 }}
protocol: TCP
+ env:
+ - name: MYSQL_ROOT_PASSWORD
+ value: 'itsASecret'
+ - name: MYSQL_USER
+ value: 'sdnctl'
+ - name: MYSQL_PASSWORD
+ value: 'gamma'
+ - name: MYSQL_DATABASE
+ value: 'sdnctl'
+ - name: SDNC_CONFIG_DIR
+ value: '/opt/onap/sdnc/data/properties'
+ - name: SDNC_BIN
+ value: '/opt/onap/sdnc/bin'
+ - name: ODL_CERT_DIR
+ value: '/tmp'
+ - name: ODL_ADMIN_USERNAME
+ value: admin
+ - name: ODL_ADMIN_PASSWORD
+ value: 'Kp8bJ4SXszM0WXlhak3eHlcse2gAw84vaoGGmJvUy2U'
+ - name: ODL_USERNAME
+ value: admin
+ - name: ODL_PASSWORD
+ value: 'Kp8bJ4SXszM0WXlhak3eHlcse2gAw84vaoGGmJvUy2U'
+ - name: SDNC_DB_INIT
+ value: 'true'
+ - name: A1_TRUSTSTORE_PASSWORD
+ value: 'a1adapter'
+ - name: AAI_TRUSTSTORE_PASSWORD
+ value: 'changeit'
readinessProbe:
tcpSocket:
port: {{ .Values.a1controller.service.targetPort1 }}
@@ -85,12 +109,12 @@
spec:
containers:
- name: sdnc-db-container
- image: mysql/mysql-server:5.6
+ image: nexus3.o-ran-sc.org:10001/mariadb:10.5
imagePullPolicy: IfNotPresent
env:
- name: MYSQL_ROOT_HOST
value: '%'
- name: MYSQL_ROOT_PASSWORD
- value: openECOMP1.0
+ value: 'itsASecret'
ports:
- containerPort: 3306
\ No newline at end of file
diff --git a/nonrtric/helm/a1controller/values.yaml b/nonrtric/helm/a1controller/values.yaml
index 11e8a0d..6f0410d 100644
--- a/nonrtric/helm/a1controller/values.yaml
+++ b/nonrtric/helm/a1controller/values.yaml
@@ -20,9 +20,9 @@
a1controller:
imagePullPolicy: IfNotPresent
image:
- registry: 'nexus3.o-ran-sc.org:10002/o-ran-sc'
- name: nonrtric-a1-controller
- tag: 2.0.1
+ registry: 'nexus3.onap.org:10002/onap'
+ name: sdnc-image
+ tag: 2.1.6
replicaCount: 1
service:
allowHttp: true
diff --git a/nonrtric/helm/a1simulator/values.yaml b/nonrtric/helm/a1simulator/values.yaml
index 9836bf2..3f587c6 100644
--- a/nonrtric/helm/a1simulator/values.yaml
+++ b/nonrtric/helm/a1simulator/values.yaml
@@ -22,9 +22,9 @@
name: a1-sim
imagePullPolicy: IfNotPresent
image:
- registry: 'nexus3.o-ran-sc.org:10002/o-ran-sc'
+ registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: a1-simulator
- tag: 2.1.0
+ tag: 2.2.0
service:
allowHttp: true
httpName: http
diff --git a/nonrtric/helm/controlpanel/resources-ing/nginx.conf b/nonrtric/helm/controlpanel/resources-ing/nginx.conf
new file mode 100644
index 0000000..d72eea7
--- /dev/null
+++ b/nonrtric/helm/controlpanel/resources-ing/nginx.conf
@@ -0,0 +1,28 @@
+events{}
+
+http {
+ include /etc/nginx/mime.types;
+
+ upstream backend {
+ server kong-proxy.kong:80;
+ }
+
+ server {
+ listen 8080;
+ server_name localhost;
+ root /usr/share/nginx/html;
+ index index.html;
+ location /a1-policy/ {
+ proxy_pass http://backend;
+ }
+ location /data-producer/ {
+ proxy_pass http://backend;
+ }
+ location /data-consumer/ {
+ proxy_pass http://backend;
+ }
+ location / {
+ try_files $uri $uri/ /index.html;
+ }
+ }
+}
\ No newline at end of file
diff --git a/nonrtric/helm/controlpanel/resources/nginx.conf b/nonrtric/helm/controlpanel/resources-ngw/nginx.conf
similarity index 100%
rename from nonrtric/helm/controlpanel/resources/nginx.conf
rename to nonrtric/helm/controlpanel/resources-ngw/nginx.conf
diff --git a/nonrtric/helm/controlpanel/templates/configmap.yaml b/nonrtric/helm/controlpanel/templates/configmap.yaml
index e351ce9..c99b92f 100644
--- a/nonrtric/helm/controlpanel/templates/configmap.yaml
+++ b/nonrtric/helm/controlpanel/templates/configmap.yaml
@@ -25,4 +25,8 @@
release: {{ .Release.Name }}
heritage: {{ .Release.Service }}
data:
-{{ tpl (.Files.Glob "resources/*").AsConfig . | indent 2 }}
\ No newline at end of file
+{{if eq .Values.controlpanel.ingress.enabled false }}
+{{ tpl (.Files.Glob "resources-ngw/*").AsConfig . | indent 2 }}
+{{ else }}
+{{ tpl (.Files.Glob "resources-ing/*").AsConfig . | indent 2 }}
+{{ end }}
\ No newline at end of file
diff --git a/nonrtric/helm/controlpanel/values.yaml b/nonrtric/helm/controlpanel/values.yaml
index ce9acbc..91f233f 100644
--- a/nonrtric/helm/controlpanel/values.yaml
+++ b/nonrtric/helm/controlpanel/values.yaml
@@ -23,7 +23,7 @@
image:
registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: nonrtric-controlpanel
- tag: 2.2.0
+ tag: 2.3.0
replicaCount: 1
service:
allowHttp: true
@@ -41,3 +41,5 @@
readiness:
initialDelaySeconds: 20
periodSeconds: 10
+ ingress:
+ enabled: true
\ No newline at end of file
diff --git a/nonrtric/helm/dmaapadapterservice/resources/config/application.yaml b/nonrtric/helm/dmaapadapterservice/resources/config/application.yaml
index a3582fb..2730af8 100644
--- a/nonrtric/helm/dmaapadapterservice/resources/config/application.yaml
+++ b/nonrtric/helm/dmaapadapterservice/resources/config/application.yaml
@@ -25,18 +25,23 @@
endpoints:
web:
exposure:
+ # Enabling of springboot actuator features. See springboot documentation.
include: "loggers,logfile,health,info,metrics,threaddump,heapdump"
-
+springdoc:
+ show-actuator: true
logging:
+ # Configuration of logging
level:
ROOT: ERROR
org.springframework: ERROR
org.springframework.data: ERROR
org.springframework.web.reactive.function.client.ExchangeFunctions: ERROR
- org.oran.dmaapadapter: INFO
+ org.oran.dmaapadapter: DEBUG
file:
name: /var/log/dmaap-adaptor-service/application.log
server:
+ # Configuration of the HTTP/REST server. The parameters are defined and handeled by the springboot framework.
+ # See springboot documentation.
port : 8435
http-port: 8084
ssl:
@@ -47,13 +52,23 @@
key-alias: policy_agent
app:
webclient:
+ # Configuration of the trust store used for the HTTP client (outgoing requests)
+ # The file location and the password for the truststore is only relevant if trust-store-used == true
+ # Note that the same keystore as for the server is used.
trust-store-used: false
trust-store-password: policy_agent
trust-store: /opt/app/dmaap-adaptor-service/etc/cert/truststore.jks
+ # Configuration of usage of HTTP Proxy for the southbound accesses.
+ # The HTTP proxy (if configured) will only be used for accessing NearRT RIC:s
http.proxy-host:
http.proxy-port: 0
- ecs-base-url: https://enrichmentservice:9083
+ ics-base-url: https://informationservice.nonrtric:9083
+ # Location of the component configuration file. The file will only be used if the Consul database is not used;
+ # configuration from the Consul will override the file.
configuration-filepath: /opt/app/dmaap-adaptor-service/data/application_configuration.json
dmaap-base-url: http://message-router.onap:3904
# The url used to adress this component. This is used as a callback url sent to other components.
- dmaap-adapter-base-url: https://dmaapadapterservice:9088
\ No newline at end of file
+ dmaap-adapter-base-url: https://dmaapadapterservice.nonrtric:9088
+ # KAFKA boostrap server. This is only needed if there are Information Types that uses a kafkaInputTopic
+ kafka:
+ bootstrap-servers: message-router-kafka.onap:9092
diff --git a/nonrtric/helm/dmaapadapterservice/resources/data/application_configuration.json b/nonrtric/helm/dmaapadapterservice/resources/data/application_configuration.json
index a8967d8..137e353 100644
--- a/nonrtric/helm/dmaapadapterservice/resources/data/application_configuration.json
+++ b/nonrtric/helm/dmaapadapterservice/resources/data/application_configuration.json
@@ -2,7 +2,13 @@
"types": [
{
"id": "ExampleInformationType",
- "dmaapTopicUrl": "/events/unauthenticated.VES_NOTIFICATION_OUTPUT/OpenDcae-c12/C12"
- }
+ "dmaapTopicUrl": "/events/unauthenticated.dmaapadp.json/dmaapadapterproducer/msgs?timeout=15000&limit=100",
+ "useHttpProxy": false
+ },
+ {
+ "id": "ExampleInformationTypeKafka",
+ "kafkaInputTopic": "unauthenticated.dmaapadp_kafka.text",
+ "useHttpProxy": false
+ }
]
-}
+ }
diff --git a/nonrtric/helm/enrichmentservice/.helmignore b/nonrtric/helm/dmaapmediatorservice/.helmignore
similarity index 100%
copy from nonrtric/helm/enrichmentservice/.helmignore
copy to nonrtric/helm/dmaapmediatorservice/.helmignore
diff --git a/nonrtric/helm/enrichmentservice/Chart.yaml b/nonrtric/helm/dmaapmediatorservice/Chart.yaml
similarity index 88%
copy from nonrtric/helm/enrichmentservice/Chart.yaml
copy to nonrtric/helm/dmaapmediatorservice/Chart.yaml
index de02e98..c78a5d0 100644
--- a/nonrtric/helm/enrichmentservice/Chart.yaml
+++ b/nonrtric/helm/dmaapmediatorservice/Chart.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -16,6 +16,6 @@
apiVersion: v1
appVersion: "1.0.0"
-description: A Helm chart for Enrichment Coordinator Service
-name: enrichmentservice
+description: A Helm chart for Dmaap Mediator Service
+name: dmaapmediatorservice
version: 1.0.0
diff --git a/nonrtric/helm/enrichmentservice/Chart.yaml b/nonrtric/helm/dmaapmediatorservice/requirements.yaml
similarity index 84%
copy from nonrtric/helm/enrichmentservice/Chart.yaml
copy to nonrtric/helm/dmaapmediatorservice/requirements.yaml
index de02e98..69b4db6 100644
--- a/nonrtric/helm/enrichmentservice/Chart.yaml
+++ b/nonrtric/helm/dmaapmediatorservice/requirements.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -14,8 +14,7 @@
# limitations under the License. #
################################################################################
-apiVersion: v1
-appVersion: "1.0.0"
-description: A Helm chart for Enrichment Coordinator Service
-name: enrichmentservice
-version: 1.0.0
+dependencies:
+ - name: nonrtric-common
+ version: ^2.0.0
+ repository: "@local"
diff --git a/nonrtric/helm/dmaapmediatorservice/resources/data/type_config.json b/nonrtric/helm/dmaapmediatorservice/resources/data/type_config.json
new file mode 100644
index 0000000..cf3855a
--- /dev/null
+++ b/nonrtric/helm/dmaapmediatorservice/resources/data/type_config.json
@@ -0,0 +1,9 @@
+{
+ "types":
+ [
+ {
+ "id": "STD_Fault_Messages",
+ "dmaapTopicUrl": "/events/unauthenticated.dmaapmed.json/dmaapmediatorproducer/STD_Fault_Messages?timeout=15000&limit=100"
+ }
+ ]
+ }
diff --git a/nonrtric/helm/enrichmentservice/templates/configmap.yaml b/nonrtric/helm/dmaapmediatorservice/templates/configmap.yaml
similarity index 85%
copy from nonrtric/helm/enrichmentservice/templates/configmap.yaml
copy to nonrtric/helm/dmaapmediatorservice/templates/configmap.yaml
index d8e4f89..0315e37 100644
--- a/nonrtric/helm/enrichmentservice/templates/configmap.yaml
+++ b/nonrtric/helm/dmaapmediatorservice/templates/configmap.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -18,12 +18,12 @@
apiVersion: v1
kind: ConfigMap
metadata:
- name: {{ include "common.name.enrichmentservice" . }}-configmap
+ name: {{ include "common.name.dmaapmediatorservice" . }}-configmap-data
namespace: {{ include "common.namespace.nonrtric" . }}
labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.dmaapmediatorservice" . }}
chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
release: {{ .Release.Name }}
heritage: {{ .Release.Service }}
data:
-{{ tpl (.Files.Glob "resources/config/*").AsConfig . | indent 2 }}
\ No newline at end of file
+{{ tpl (.Files.Glob "resources/data/*").AsConfig . | indent 2 }}
\ No newline at end of file
diff --git a/nonrtric/helm/enrichmentservice/templates/service.yaml b/nonrtric/helm/dmaapmediatorservice/templates/service.yaml
similarity index 70%
copy from nonrtric/helm/enrichmentservice/templates/service.yaml
copy to nonrtric/helm/dmaapmediatorservice/templates/service.yaml
index 0b2a110..d09fde4 100644
--- a/nonrtric/helm/enrichmentservice/templates/service.yaml
+++ b/nonrtric/helm/dmaapmediatorservice/templates/service.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -17,26 +17,26 @@
kind: Service
apiVersion: v1
metadata:
- name: {{ include "common.name.enrichmentservice" . }}
+ name: {{ include "common.name.dmaapmediatorservice" . }}
namespace: {{ include "common.namespace.nonrtric" . }}
labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.dmaapmediatorservice" . }}
chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
release: {{ .Release.Name }}
heritage: {{ .Release.Service }}
spec:
ports:
- {{if eq .Values.enrichmentservice.service.allowHttp true -}}
- - name: {{ index .Values.enrichmentservice.service.httpName }}
- port: {{ .Values.enrichmentservice.service.internalPort1 }}
- targetPort: {{ .Values.enrichmentservice.service.targetPort1 }}
+ {{if eq .Values.dmaapmediatorservice.service.allowHttp true -}}
+ - name: {{ index .Values.dmaapmediatorservice.service.httpName }}
+ port: {{ .Values.dmaapmediatorservice.service.internalPort1 }}
+ targetPort: {{ .Values.dmaapmediatorservice.service.targetPort1 }}
protocol: TCP
{{- end }}
- - name: {{ index .Values.enrichmentservice.service.httpsName }}
- port: {{ .Values.enrichmentservice.service.internalPort2 }}
- targetPort: {{ .Values.enrichmentservice.service.targetPort2 }}
+ - name: {{ index .Values.dmaapmediatorservice.service.httpsName }}
+ port: {{ .Values.dmaapmediatorservice.service.internalPort2 }}
+ targetPort: {{ .Values.dmaapmediatorservice.service.targetPort2 }}
protocol: TCP
selector:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.dmaapmediatorservice" . }}
release: {{ .Release.Name }}
type: ClusterIP
diff --git a/nonrtric/helm/dmaapmediatorservice/templates/statefulset.yaml b/nonrtric/helm/dmaapmediatorservice/templates/statefulset.yaml
new file mode 100644
index 0000000..ae3971d
--- /dev/null
+++ b/nonrtric/helm/dmaapmediatorservice/templates/statefulset.yaml
@@ -0,0 +1,83 @@
+################################################################################
+# Copyright (c) 2021 Nordix Foundation. #
+# #
+# Licensed under the Apache License, Version 2.0 (the "License"); #
+# you may not use this file except in compliance with the License. #
+# You may obtain a copy of the License at #
+# #
+# http://www.apache.org/licenses/LICENSE-2.0 #
+# #
+# Unless required by applicable law or agreed to in writing, software #
+# distributed under the License is distributed on an "AS IS" BASIS, #
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
+# See the License for the specific language governing permissions and #
+# limitations under the License. #
+################################################################################
+
+kind: StatefulSet
+apiVersion: apps/v1
+metadata:
+ name: {{ include "common.name.dmaapmediatorservice" . }}
+ namespace: {{ include "common.namespace.nonrtric" . }}
+ generation: 1
+ labels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.dmaapmediatorservice" . }}
+ chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
+ release: {{ .Release.Name }}
+ heritage: {{ .Release.Service }}
+ annotations:
+ deployment.kubernetes.io/revision: '1'
+spec:
+ serviceName: {{ include "common.name.dmaapmediatorservice" . }}
+ replicas: 1
+ selector:
+ matchLabels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.dmaapmediatorservice" . }}
+ release: {{ .Release.Name }}
+ template:
+ metadata:
+ labels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.dmaapmediatorservice" . }}
+ release: {{ .Release.Name }}
+ spec:
+ hostname: {{ include "common.name.dmaapmediatorservice" . }}
+ containers:
+ - name: {{ include "common.container.dmaapmediatorservice" . }}
+ image: {{ .Values.dmaapmediatorservice.image.registry }}/{{ .Values.dmaapmediatorservice.image.name }}:{{ .Values.dmaapmediatorservice.image.tag }}
+ imagePullPolicy: {{ .Values.dmaapmediatorservice.imagePullPolicy }}
+ ports:
+ - containerPort: {{ .Values.dmaapmediatorservice.service.targetPort1 }}
+ protocol: TCP
+ - containerPort: {{ .Values.dmaapmediatorservice.service.targetPort2 }}
+ protocol: TCP
+ # Temporarily disabled probes due to no http available in the container
+ # readinessProbe:
+ # tcpSocket:
+ # port: {{ .Values.dmaapmediatorservice.service.targetPort1 }}
+ # initialDelaySeconds: {{ .Values.dmaapmediatorservice.liveness.initialDelaySeconds }}
+ # periodSeconds: {{ .Values.dmaapmediatorservice.liveness.periodSeconds }}
+ # livenessProbe:
+ # tcpSocket:
+ # port: {{ .Values.dmaapmediatorservice.service.targetPort1 }}
+ # initialDelaySeconds: {{ .Values.dmaapmediatorservice.liveness.initialDelaySeconds }}
+ # periodSeconds: {{ .Values.dmaapmediatorservice.liveness.periodSeconds }}
+ volumeMounts:
+ - name: {{ include "common.name.dmaapmediatorservice" . }}-dmaapmediator-data
+ mountPath: /configs/type_config.json
+ subPath: type_config.json
+
+ env:
+ - name: INFO_PRODUCER_HOST
+ value: https://{{ include "common.name.dmaapmediatorservice" . }}
+ - name: INFO_PRODUCER_PORT
+ value: "{{ .Values.dmaapmediatorservice.service.internalPort2 }}"
+ - name: INFO_COORD_ADDR
+ value: https://informationservice:9083
+ - name: DMAAP_MR_ADDR
+ value: https://message-router.onap:3905
+ - name: LOG_LEVEL
+ value: Info
+ volumes:
+ - name: {{ include "common.name.dmaapmediatorservice" . }}-dmaapmediator-data
+ configMap:
+ name: {{ include "common.name.dmaapmediatorservice" . }}-configmap-data
diff --git a/nonrtric/helm/enrichmentservice/values.yaml b/nonrtric/helm/dmaapmediatorservice/values.yaml
similarity index 79%
copy from nonrtric/helm/enrichmentservice/values.yaml
copy to nonrtric/helm/dmaapmediatorservice/values.yaml
index 32eb4a7..4a32b42 100644
--- a/nonrtric/helm/enrichmentservice/values.yaml
+++ b/nonrtric/helm/dmaapmediatorservice/values.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -14,32 +14,27 @@
# limitations under the License. #
################################################################################
-# Default values for Enrichment Coordinate Service.
+# Default values for Dmaap Adapter Service.
# This is a YAML-formatted file.
# Declare variables to be passed into your templates.
-enrichmentservice:
+dmaapmediatorservice:
imagePullPolicy: IfNotPresent
image:
registry: "nexus3.o-ran-sc.org:10004/o-ran-sc"
- name: "nonrtric-enrichment-coordinator-service"
- tag: 1.2.0
+ name: "nonrtric-dmaap-mediator-producer"
+ tag: 1.0.0
service:
allowHttp: true
httpName: http
- internalPort1: 9082
- targetPort1: 8083
+ internalPort1: 8085
+ targetPort1: 8085
httpsName: https
- internalPort2: 9083
- targetPort2: 8434
+ internalPort2: 8185
+ targetPort2: 8185
liveness:
initialDelaySeconds: 20
periodSeconds: 10
readiness:
initialDelaySeconds: 20
periodSeconds: 10
- persistence:
- size: 2Gi
- storageClassName: standard
- ingress:
- enabled: false
diff --git a/nonrtric/helm/enrichmentservice/templates/statefulset.yaml b/nonrtric/helm/enrichmentservice/templates/statefulset.yaml
deleted file mode 100644
index 678e8b1..0000000
--- a/nonrtric/helm/enrichmentservice/templates/statefulset.yaml
+++ /dev/null
@@ -1,82 +0,0 @@
-################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
-# #
-# Licensed under the Apache License, Version 2.0 (the "License"); #
-# you may not use this file except in compliance with the License. #
-# You may obtain a copy of the License at #
-# #
-# http://www.apache.org/licenses/LICENSE-2.0 #
-# #
-# Unless required by applicable law or agreed to in writing, software #
-# distributed under the License is distributed on an "AS IS" BASIS, #
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
-# See the License for the specific language governing permissions and #
-# limitations under the License. #
-################################################################################
-
-kind: StatefulSet
-apiVersion: apps/v1
-metadata:
- name: {{ include "common.name.enrichmentservice" . }}
- namespace: {{ include "common.namespace.nonrtric" . }}
- generation: 1
- labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
- chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
- release: {{ .Release.Name }}
- heritage: {{ .Release.Service }}
- annotations:
- deployment.kubernetes.io/revision: '1'
-spec:
- serviceName: {{ include "common.name.enrichmentservice" . }}
- replicas: 1
- selector:
- matchLabels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
- release: {{ .Release.Name }}
- template:
- metadata:
- labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
- release: {{ .Release.Name }}
- spec:
- hostname: {{ include "common.name.enrichmentservice" . }}
- containers:
- - name: {{ include "common.container.enrichmentservice" . }}
- image: {{ .Values.enrichmentservice.image.registry }}/{{ .Values.enrichmentservice.image.name }}:{{ .Values.enrichmentservice.image.tag }}
- imagePullPolicy: {{ .Values.enrichmentservice.imagePullPolicy }}
- ports:
- - containerPort: {{ .Values.enrichmentservice.service.targetPort1 }}
- protocol: TCP
- - containerPort: {{ .Values.enrichmentservice.service.targetPort2 }}
- protocol: TCP
- readinessProbe:
- tcpSocket:
- port: {{ .Values.enrichmentservice.service.targetPort1 }}
- initialDelaySeconds: {{ .Values.enrichmentservice.liveness.initialDelaySeconds }}
- periodSeconds: {{ .Values.enrichmentservice.liveness.periodSeconds }}
- livenessProbe:
- httpGet:
- path: /status
- port: {{ .Values.enrichmentservice.service.targetPort1 }}
- initialDelaySeconds: {{ .Values.enrichmentservice.liveness.initialDelaySeconds }}
- periodSeconds: {{ .Values.enrichmentservice.liveness.periodSeconds }}
- volumeMounts:
- - name: {{ include "common.name.enrichmentservice" . }}-enrichment-config
- mountPath: /opt/app/enrichment-coordinator-service/config
- - name: {{ include "common.name.enrichmentservice" . }}-vardata
- mountPath: /var/enrichment-coordinator-service
- volumes:
- - name: {{ include "common.name.enrichmentservice" . }}-enrichment-config
- configMap:
- name: {{ include "common.name.enrichmentservice" . }}-configmap
-
- volumeClaimTemplates:
- - metadata:
- name: {{ include "common.name.enrichmentservice" . }}-vardata
- spec:
- accessModes: [ ReadWriteOnce ]
- storageClassName: "{{ .Values.enrichmentservice.persistence.storageClassName }}"
- resources:
- requests:
- storage: "{{ .Values.enrichmentservice.persistence.size }}"
diff --git a/nonrtric/helm/enrichmentservice/.helmignore b/nonrtric/helm/helmmanager/.helmignore
similarity index 100%
copy from nonrtric/helm/enrichmentservice/.helmignore
copy to nonrtric/helm/helmmanager/.helmignore
diff --git a/nonrtric/helm/enrichmentservice/Chart.yaml b/nonrtric/helm/helmmanager/Chart.yaml
similarity index 88%
copy from nonrtric/helm/enrichmentservice/Chart.yaml
copy to nonrtric/helm/helmmanager/Chart.yaml
index de02e98..ab2d5a0 100644
--- a/nonrtric/helm/enrichmentservice/Chart.yaml
+++ b/nonrtric/helm/helmmanager/Chart.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -16,6 +16,6 @@
apiVersion: v1
appVersion: "1.0.0"
-description: A Helm chart for Enrichment Coordinator Service
-name: enrichmentservice
+description: A Helm chart for Helm Manager
+name: helmmanager
version: 1.0.0
diff --git a/nonrtric/helm/enrichmentservice/Chart.yaml b/nonrtric/helm/helmmanager/requirements.yaml
similarity index 84%
copy from nonrtric/helm/enrichmentservice/Chart.yaml
copy to nonrtric/helm/helmmanager/requirements.yaml
index de02e98..69b4db6 100644
--- a/nonrtric/helm/enrichmentservice/Chart.yaml
+++ b/nonrtric/helm/helmmanager/requirements.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -14,8 +14,7 @@
# limitations under the License. #
################################################################################
-apiVersion: v1
-appVersion: "1.0.0"
-description: A Helm chart for Enrichment Coordinator Service
-name: enrichmentservice
-version: 1.0.0
+dependencies:
+ - name: nonrtric-common
+ version: ^2.0.0
+ repository: "@local"
diff --git a/nonrtric/helm/enrichmentservice/templates/configmap.yaml b/nonrtric/helm/helmmanager/templates/service.yaml
similarity index 72%
copy from nonrtric/helm/enrichmentservice/templates/configmap.yaml
copy to nonrtric/helm/helmmanager/templates/service.yaml
index d8e4f89..4fab625 100644
--- a/nonrtric/helm/enrichmentservice/templates/configmap.yaml
+++ b/nonrtric/helm/helmmanager/templates/service.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -14,16 +14,23 @@
# limitations under the License. #
################################################################################
-
+kind: Service
apiVersion: v1
-kind: ConfigMap
metadata:
- name: {{ include "common.name.enrichmentservice" . }}-configmap
+ name: {{ include "common.name.helmmanager" . }}
namespace: {{ include "common.namespace.nonrtric" . }}
labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.helmmanager" . }}
chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
release: {{ .Release.Name }}
heritage: {{ .Release.Service }}
-data:
-{{ tpl (.Files.Glob "resources/config/*").AsConfig . | indent 2 }}
\ No newline at end of file
+spec:
+ ports:
+ - name: {{ index .Values.helmmanager.service.httpName }}
+ port: {{ .Values.helmmanager.service.internalPort1 }}
+ targetPort: {{ .Values.helmmanager.service.targetPort1 }}
+ protocol: TCP
+ selector:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.helmmanager" . }}
+ release: {{ .Release.Name }}
+ type: ClusterIP
diff --git a/nonrtric/helm/enrichmentservice/templates/configmap.yaml b/nonrtric/helm/helmmanager/templates/serviceaccount.yaml
similarity index 67%
copy from nonrtric/helm/enrichmentservice/templates/configmap.yaml
copy to nonrtric/helm/helmmanager/templates/serviceaccount.yaml
index d8e4f89..0e5ea20 100644
--- a/nonrtric/helm/enrichmentservice/templates/configmap.yaml
+++ b/nonrtric/helm/helmmanager/templates/serviceaccount.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -16,14 +16,28 @@
apiVersion: v1
-kind: ConfigMap
+kind: ServiceAccount
metadata:
- name: {{ include "common.name.enrichmentservice" . }}-configmap
+ name: {{ include "common.namespace.nonrtric" . }}-helm-manager-sa
namespace: {{ include "common.namespace.nonrtric" . }}
labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.helmmanager" . }}
chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
release: {{ .Release.Name }}
heritage: {{ .Release.Service }}
-data:
-{{ tpl (.Files.Glob "resources/config/*").AsConfig . | indent 2 }}
\ No newline at end of file
+ annotations:
+
+---
+apiVersion: rbac.authorization.k8s.io/v1
+kind: ClusterRoleBinding
+metadata:
+ name: {{ include "common.namespace.nonrtric" . }}-helm-manager-sa-clusterrolebinding
+ namespace: {{ include "common.namespace.nonrtric" . }}
+subjects:
+- kind: ServiceAccount
+ name: {{ include "common.namespace.nonrtric" . }}-helm-manager-sa
+ namespace: {{ include "common.namespace.nonrtric" . }}
+roleRef:
+ kind: ClusterRole
+ name: {{ .Values.helmmanager.clusterRoleName }}
+ apiGroup: rbac.authorization.k8s.io
\ No newline at end of file
diff --git a/nonrtric/helm/helmmanager/templates/statefulset.yaml b/nonrtric/helm/helmmanager/templates/statefulset.yaml
new file mode 100644
index 0000000..668ac5f
--- /dev/null
+++ b/nonrtric/helm/helmmanager/templates/statefulset.yaml
@@ -0,0 +1,74 @@
+################################################################################
+# Copyright (c) 2021 Nordix Foundation. #
+# #
+# Licensed under the Apache License, Version 2.0 (the "License"); #
+# you may not use this file except in compliance with the License. #
+# You may obtain a copy of the License at #
+# #
+# http://www.apache.org/licenses/LICENSE-2.0 #
+# #
+# Unless required by applicable law or agreed to in writing, software #
+# distributed under the License is distributed on an "AS IS" BASIS, #
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
+# See the License for the specific language governing permissions and #
+# limitations under the License. #
+################################################################################
+
+kind: StatefulSet
+apiVersion: apps/v1
+metadata:
+ name: {{ include "common.name.helmmanager" . }}
+ namespace: {{ include "common.namespace.nonrtric" . }}
+ generation: 1
+ labels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.helmmanager" . }}
+ chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
+ release: {{ .Release.Name }}
+ heritage: {{ .Release.Service }}
+ annotations:
+
+spec:
+ serviceName: {{ include "common.name.helmmanager" . }}
+ replicas: 1
+ selector:
+ matchLabels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.helmmanager" . }}
+ release: {{ .Release.Name }}
+ template:
+ metadata:
+ labels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.helmmanager" . }}
+ release: {{ .Release.Name }}
+ spec:
+ hostname: {{ include "common.name.helmmanager" . }}
+ containers:
+ - name: {{ include "common.container.helmmanager" . }}
+ image: {{ .Values.helmmanager.image.registry }}/{{ .Values.helmmanager.image.name }}:{{ .Values.helmmanager.image.tag }}
+ imagePullPolicy: {{ .Values.helmmanager.imagePullPolicy }}
+ ports:
+ - containerPort: {{ .Values.helmmanager.service.targetPort1 }}
+ protocol: TCP
+ # readinessProbe:
+ # tcpSocket:
+ # port: {{ .Values.helmmanager.service.targetPort1 }}
+ # initialDelaySeconds: {{ .Values.helmmanager.liveness.initialDelaySeconds }}
+ # periodSeconds: {{ .Values.helmmanager.liveness.periodSeconds }}
+ # livenessProbe:
+ # httpGet:
+ # path: /helm/charts
+ # port: {{ .Values.helmmanager.service.targetPort1 }}
+ # initialDelaySeconds: {{ .Values.helmmanager.liveness.initialDelaySeconds }}
+ # periodSeconds: {{ .Values.helmmanager.liveness.periodSeconds }}
+ volumeMounts:
+ - name: {{ include "common.name.helmmanager" . }}-vardata
+ mountPath: "/var/helm-manager-service"
+ volumeClaimTemplates:
+ - metadata:
+ name: {{ include "common.name.helmmanager" . }}-vardata
+ spec:
+ accessModes:
+ - ReadWriteOnce
+ storageClassName: "{{ .Values.helmmanager.persistence.storageClassName }}"
+ resources:
+ requests:
+ storage: "{{ .Values.helmmanager.persistence.size }}"
diff --git a/nonrtric/helm/enrichmentservice/values.yaml b/nonrtric/helm/helmmanager/values.yaml
similarity index 81%
copy from nonrtric/helm/enrichmentservice/values.yaml
copy to nonrtric/helm/helmmanager/values.yaml
index 32eb4a7..40ef634 100644
--- a/nonrtric/helm/enrichmentservice/values.yaml
+++ b/nonrtric/helm/helmmanager/values.yaml
@@ -1,5 +1,5 @@
################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -14,24 +14,21 @@
# limitations under the License. #
################################################################################
-# Default values for Enrichment Coordinate Service.
+# Default values for Helm Manager
# This is a YAML-formatted file.
# Declare variables to be passed into your templates.
-enrichmentservice:
+helmmanager:
+ clusterRoleName: cluster-admin
imagePullPolicy: IfNotPresent
image:
registry: "nexus3.o-ran-sc.org:10004/o-ran-sc"
- name: "nonrtric-enrichment-coordinator-service"
- tag: 1.2.0
+ name: "nonrtric-helm-manager"
+ tag: 1.1.0
service:
- allowHttp: true
httpName: http
- internalPort1: 9082
+ internalPort1: 8112
targetPort1: 8083
- httpsName: https
- internalPort2: 9083
- targetPort2: 8434
liveness:
initialDelaySeconds: 20
periodSeconds: 10
@@ -39,7 +36,5 @@
initialDelaySeconds: 20
periodSeconds: 10
persistence:
- size: 2Gi
- storageClassName: standard
- ingress:
- enabled: false
+ size: 1Gi
+ storageClassName: standard
\ No newline at end of file
diff --git a/nonrtric/helm/enrichmentservice/.helmignore b/nonrtric/helm/informationservice/.helmignore
similarity index 100%
rename from nonrtric/helm/enrichmentservice/.helmignore
rename to nonrtric/helm/informationservice/.helmignore
diff --git a/nonrtric/helm/enrichmentservice/Chart.yaml b/nonrtric/helm/informationservice/Chart.yaml
similarity index 93%
rename from nonrtric/helm/enrichmentservice/Chart.yaml
rename to nonrtric/helm/informationservice/Chart.yaml
index de02e98..610411b 100644
--- a/nonrtric/helm/enrichmentservice/Chart.yaml
+++ b/nonrtric/helm/informationservice/Chart.yaml
@@ -16,6 +16,6 @@
apiVersion: v1
appVersion: "1.0.0"
-description: A Helm chart for Enrichment Coordinator Service
-name: enrichmentservice
+description: A Helm chart for Information Coordinator Service
+name: informationservice
version: 1.0.0
diff --git a/nonrtric/helm/enrichmentservice/requirements.yaml b/nonrtric/helm/informationservice/requirements.yaml
similarity index 100%
rename from nonrtric/helm/enrichmentservice/requirements.yaml
rename to nonrtric/helm/informationservice/requirements.yaml
diff --git a/nonrtric/helm/enrichmentservice/resources/config/application.yaml b/nonrtric/helm/informationservice/resources/config/application.yaml
similarity index 75%
rename from nonrtric/helm/enrichmentservice/resources/config/application.yaml
rename to nonrtric/helm/informationservice/resources/config/application.yaml
index 75b11ad..5d949a9 100644
--- a/nonrtric/helm/enrichmentservice/resources/config/application.yaml
+++ b/nonrtric/helm/informationservice/resources/config/application.yaml
@@ -33,22 +33,26 @@
org.springframework: ERROR
org.springframework.data: ERROR
org.springframework.web.reactive.function.client.ExchangeFunctions: ERROR
- org.oransc.enrichment: INFO
+ org.oransc.information: INFO
file:
- name: /var/log/enrichment-coordinator-service/application.log
+ name: /var/log/information-coordinator-service/application.log
server:
port : 8434
http-port: 8083
ssl:
key-store-type: JKS
key-store-password: policy_agent
- key-store: /opt/app/enrichment-coordinator-service/etc/cert/keystore.jks
+ key-store: /opt/app/information-coordinator-service/etc/cert/keystore.jks
key-password: policy_agent
key-alias: policy_agent
app:
- filepath: /opt/app/enrichment-coordinator-service/data/application_configuration.json
+ filepath: /opt/app/information-coordinator-service/data/application_configuration.json
webclient:
trust-store-used: false
trust-store-password: policy_agent
- trust-store: /opt/app/enrichment-coordinator-service/etc/cert/truststore.jks
- vardata-directory: /var/enrichment-coordinator-service
\ No newline at end of file
+ trust-store: /opt/app/information-coordinator-service/etc/cert/truststore.jks
+ # Configuration of usage of HTTP Proxy for the southbound accesses.
+ # The HTTP proxy (if configured) will only be used for accessing NearRT RIC:s
+ http.proxy-host:
+ http.proxy-port: 0
+ vardata-directory: /var/information-coordinator-service
\ No newline at end of file
diff --git a/nonrtric/helm/enrichmentservice/templates/configmap.yaml b/nonrtric/helm/informationservice/templates/configmap.yaml
similarity index 93%
rename from nonrtric/helm/enrichmentservice/templates/configmap.yaml
rename to nonrtric/helm/informationservice/templates/configmap.yaml
index d8e4f89..d8b198d 100644
--- a/nonrtric/helm/enrichmentservice/templates/configmap.yaml
+++ b/nonrtric/helm/informationservice/templates/configmap.yaml
@@ -18,10 +18,10 @@
apiVersion: v1
kind: ConfigMap
metadata:
- name: {{ include "common.name.enrichmentservice" . }}-configmap
+ name: {{ include "common.name.informationservice" . }}-configmap
namespace: {{ include "common.namespace.nonrtric" . }}
labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.informationservice" . }}
chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
release: {{ .Release.Name }}
heritage: {{ .Release.Service }}
diff --git a/nonrtric/helm/enrichmentservice/templates/ingress.yaml b/nonrtric/helm/informationservice/templates/ingress.yaml
similarity index 80%
rename from nonrtric/helm/enrichmentservice/templates/ingress.yaml
rename to nonrtric/helm/informationservice/templates/ingress.yaml
index deb3b54..9387bdc 100644
--- a/nonrtric/helm/enrichmentservice/templates/ingress.yaml
+++ b/nonrtric/helm/informationservice/templates/ingress.yaml
@@ -16,11 +16,11 @@
################################################################################
*/}}
-{{- if .Values.enrichmentservice.ingress.enabled -}}
+{{- if .Values.informationservice.ingress.enabled -}}
apiVersion: networking.k8s.io/v1
kind: Ingress
metadata:
- name: {{ include "common.name.enrichmentservice" . }}
+ name: {{ include "common.name.informationservice" . }}
namespace: {{ include "common.namespace.nonrtric" . }}
spec:
@@ -31,15 +31,15 @@
- path: "/data-producer"
backend:
service:
- name: {{ include "common.name.enrichmentservice" . }}
+ name: {{ include "common.name.informationservice" . }}
port:
- number: {{ .Values.enrichmentservice.service.internalPort1 }}
+ number: {{ .Values.informationservice.service.internalPort1 }}
pathType: Prefix
- path: "/data-consumer"
backend:
service:
- name: {{ include "common.name.enrichmentservice" . }}
+ name: {{ include "common.name.informationservice" . }}
port:
- number: {{ .Values.enrichmentservice.service.internalPort1 }}
+ number: {{ .Values.informationservice.service.internalPort1 }}
pathType: Prefix
{{- end -}}
\ No newline at end of file
diff --git a/nonrtric/helm/enrichmentservice/templates/service.yaml b/nonrtric/helm/informationservice/templates/service.yaml
similarity index 74%
rename from nonrtric/helm/enrichmentservice/templates/service.yaml
rename to nonrtric/helm/informationservice/templates/service.yaml
index 0b2a110..ba5783c 100644
--- a/nonrtric/helm/enrichmentservice/templates/service.yaml
+++ b/nonrtric/helm/informationservice/templates/service.yaml
@@ -17,26 +17,26 @@
kind: Service
apiVersion: v1
metadata:
- name: {{ include "common.name.enrichmentservice" . }}
+ name: {{ include "common.name.informationservice" . }}
namespace: {{ include "common.namespace.nonrtric" . }}
labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.informationservice" . }}
chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
release: {{ .Release.Name }}
heritage: {{ .Release.Service }}
spec:
ports:
- {{if eq .Values.enrichmentservice.service.allowHttp true -}}
- - name: {{ index .Values.enrichmentservice.service.httpName }}
- port: {{ .Values.enrichmentservice.service.internalPort1 }}
- targetPort: {{ .Values.enrichmentservice.service.targetPort1 }}
+ {{if eq .Values.informationservice.service.allowHttp true -}}
+ - name: {{ index .Values.informationservice.service.httpName }}
+ port: {{ .Values.informationservice.service.internalPort1 }}
+ targetPort: {{ .Values.informationservice.service.targetPort1 }}
protocol: TCP
{{- end }}
- - name: {{ index .Values.enrichmentservice.service.httpsName }}
- port: {{ .Values.enrichmentservice.service.internalPort2 }}
- targetPort: {{ .Values.enrichmentservice.service.targetPort2 }}
+ - name: {{ index .Values.informationservice.service.httpsName }}
+ port: {{ .Values.informationservice.service.internalPort2 }}
+ targetPort: {{ .Values.informationservice.service.targetPort2 }}
protocol: TCP
selector:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.informationservice" . }}
release: {{ .Release.Name }}
type: ClusterIP
diff --git a/nonrtric/helm/informationservice/templates/statefulset.yaml b/nonrtric/helm/informationservice/templates/statefulset.yaml
new file mode 100644
index 0000000..a597324
--- /dev/null
+++ b/nonrtric/helm/informationservice/templates/statefulset.yaml
@@ -0,0 +1,82 @@
+################################################################################
+# Copyright (c) 2020 Nordix Foundation. #
+# #
+# Licensed under the Apache License, Version 2.0 (the "License"); #
+# you may not use this file except in compliance with the License. #
+# You may obtain a copy of the License at #
+# #
+# http://www.apache.org/licenses/LICENSE-2.0 #
+# #
+# Unless required by applicable law or agreed to in writing, software #
+# distributed under the License is distributed on an "AS IS" BASIS, #
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
+# See the License for the specific language governing permissions and #
+# limitations under the License. #
+################################################################################
+
+kind: StatefulSet
+apiVersion: apps/v1
+metadata:
+ name: {{ include "common.name.informationservice" . }}
+ namespace: {{ include "common.namespace.nonrtric" . }}
+ generation: 1
+ labels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.informationservice" . }}
+ chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
+ release: {{ .Release.Name }}
+ heritage: {{ .Release.Service }}
+ annotations:
+ deployment.kubernetes.io/revision: '1'
+spec:
+ serviceName: {{ include "common.name.informationservice" . }}
+ replicas: 1
+ selector:
+ matchLabels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.informationservice" . }}
+ release: {{ .Release.Name }}
+ template:
+ metadata:
+ labels:
+ app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.informationservice" . }}
+ release: {{ .Release.Name }}
+ spec:
+ hostname: {{ include "common.name.informationservice" . }}
+ containers:
+ - name: {{ include "common.container.informationservice" . }}
+ image: {{ .Values.informationservice.image.registry }}/{{ .Values.informationservice.image.name }}:{{ .Values.informationservice.image.tag }}
+ imagePullPolicy: {{ .Values.informationservice.imagePullPolicy }}
+ ports:
+ - containerPort: {{ .Values.informationservice.service.targetPort1 }}
+ protocol: TCP
+ - containerPort: {{ .Values.informationservice.service.targetPort2 }}
+ protocol: TCP
+ readinessProbe:
+ tcpSocket:
+ port: {{ .Values.informationservice.service.targetPort1 }}
+ initialDelaySeconds: {{ .Values.informationservice.liveness.initialDelaySeconds }}
+ periodSeconds: {{ .Values.informationservice.liveness.periodSeconds }}
+ livenessProbe:
+ httpGet:
+ path: /status
+ port: {{ .Values.informationservice.service.targetPort1 }}
+ initialDelaySeconds: {{ .Values.informationservice.liveness.initialDelaySeconds }}
+ periodSeconds: {{ .Values.informationservice.liveness.periodSeconds }}
+ volumeMounts:
+ - name: {{ include "common.name.informationservice" . }}-information-config
+ mountPath: /opt/app/information-coordinator-service/config
+ - name: {{ include "common.name.informationservice" . }}-vardata
+ mountPath: /var/information-coordinator-service
+ volumes:
+ - name: {{ include "common.name.informationservice" . }}-information-config
+ configMap:
+ name: {{ include "common.name.informationservice" . }}-configmap
+
+ volumeClaimTemplates:
+ - metadata:
+ name: {{ include "common.name.informationservice" . }}-vardata
+ spec:
+ accessModes: [ ReadWriteOnce ]
+ storageClassName: "{{ .Values.informationservice.persistence.storageClassName }}"
+ resources:
+ requests:
+ storage: "{{ .Values.informationservice.persistence.size }}"
diff --git a/nonrtric/helm/enrichmentservice/values.yaml b/nonrtric/helm/informationservice/values.yaml
similarity index 93%
rename from nonrtric/helm/enrichmentservice/values.yaml
rename to nonrtric/helm/informationservice/values.yaml
index 32eb4a7..e998656 100644
--- a/nonrtric/helm/enrichmentservice/values.yaml
+++ b/nonrtric/helm/informationservice/values.yaml
@@ -14,15 +14,15 @@
# limitations under the License. #
################################################################################
-# Default values for Enrichment Coordinate Service.
+# Default values for Information Coordinate Service.
# This is a YAML-formatted file.
# Declare variables to be passed into your templates.
-enrichmentservice:
+informationservice:
imagePullPolicy: IfNotPresent
image:
registry: "nexus3.o-ran-sc.org:10004/o-ran-sc"
- name: "nonrtric-enrichment-coordinator-service"
+ name: "nonrtric-information-coordinator-service"
tag: 1.2.0
service:
allowHttp: true
diff --git a/nonrtric/helm/nonrtric/Chart.yaml b/nonrtric/helm/nonrtric/Chart.yaml
index 7c70488..76422ff 100644
--- a/nonrtric/helm/nonrtric/Chart.yaml
+++ b/nonrtric/helm/nonrtric/Chart.yaml
@@ -40,10 +40,10 @@
repository: "@local"
condition: nonrtric.installPms
- - name: enrichmentservice
+ - name: informationservice
version: ~1.0.0
repository: "@local"
- condition: nonrtric.installEnrichmentservice
+ condition: nonrtric.installInformationservice
- name: nonrtric-common
version: ^2.0.0
@@ -64,3 +64,14 @@
version: ~1.0.0
repository: "@local"
condition: nonrtric.installDmaapadapterservice
+
+ - name: dmaapmediatorservice
+ version: ~1.0.0
+ repository: "@local"
+ condition: nonrtric.installDmaapmediatorservice
+
+ - name: helmmanager
+ version: ~1.0.0
+ repository: "@local"
+ condition: nonrtric.installHelmmanager
+
diff --git a/nonrtric/helm/enrichmentservice/templates/configmap.yaml b/nonrtric/helm/nonrtric/templates/pv3.yaml
similarity index 71%
copy from nonrtric/helm/enrichmentservice/templates/configmap.yaml
copy to nonrtric/helm/nonrtric/templates/pv3.yaml
index d8e4f89..c0382f0 100644
--- a/nonrtric/helm/enrichmentservice/templates/configmap.yaml
+++ b/nonrtric/helm/nonrtric/templates/pv3.yaml
@@ -1,5 +1,5 @@
-################################################################################
-# Copyright (c) 2020 Nordix Foundation. #
+###############################################################################
+# Copyright (c) 2021 Nordix Foundation. #
# #
# Licensed under the Apache License, Version 2.0 (the "License"); #
# you may not use this file except in compliance with the License. #
@@ -14,16 +14,23 @@
# limitations under the License. #
################################################################################
+{{- if .Values.nonrtric.volume3.size }}
+kind: PersistentVolume
apiVersion: v1
-kind: ConfigMap
metadata:
- name: {{ include "common.name.enrichmentservice" . }}-configmap
+ name: nonrtric-pv3
namespace: {{ include "common.namespace.nonrtric" . }}
- labels:
- app: {{ include "common.namespace.nonrtric" . }}-{{ include "common.name.enrichmentservice" . }}
- chart: {{ .Chart.Name }}-{{ .Chart.Version | replace "+" "_" }}
- release: {{ .Release.Name }}
- heritage: {{ .Release.Service }}
-data:
-{{ tpl (.Files.Glob "resources/config/*").AsConfig . | indent 2 }}
\ No newline at end of file
+spec:
+ capacity:
+ storage: {{ .Values.nonrtric.volume3.size }}
+ accessModes:
+ - ReadWriteOnce
+ - ReadWriteMany
+ persistentVolumeReclaimPolicy: Retain
+ hostPath:
+ path: /dockerdata-nfs/nonrtric/volume3
+ storageClassName: {{ .Values.nonrtric.volume3.storageClassName }}
+
+{{- end }}
+
diff --git a/nonrtric/helm/nonrtric/values.yaml b/nonrtric/helm/nonrtric/values.yaml
index c7cd68b..4b07fb9 100644
--- a/nonrtric/helm/nonrtric/values.yaml
+++ b/nonrtric/helm/nonrtric/values.yaml
@@ -19,13 +19,18 @@
installA1controller: true
installA1simulator: true
installControlpanel: true
- installEnrichmentservice: true
+ installInformationservice: true
installRappcatalogueservice: true
installNonrtricgateway: true
installDmaapadapterservice: true
+ installDmaapmediatorservice: true
+ installHelmmanager: true
volume1:
size: 1Gi
storageClassName: volume1
volume2:
size: 1Gi
- storageClassName: volume2
\ No newline at end of file
+ storageClassName: volume2
+ volume3:
+ size: 1Gi
+ storageClassName: volume3
\ No newline at end of file
diff --git a/nonrtric/helm/nonrtricgateway/resources/config/application.yaml b/nonrtric/helm/nonrtricgateway/resources/config/application.yaml
index 124e23c..0d96d68 100644
--- a/nonrtric/helm/nonrtricgateway/resources/config/application.yaml
+++ b/nonrtric/helm/nonrtricgateway/resources/config/application.yaml
@@ -31,7 +31,7 @@
predicates:
- Path=/a1-policy/**
- id: A1-EI
- uri: https://enrichmentservice:9083
+ uri: https://informationservice:9083
predicates:
- Path=/data-producer/**,/data-consumer/**
management:
diff --git a/nonrtric/helm/nonrtricgateway/values.yaml b/nonrtric/helm/nonrtricgateway/values.yaml
index 6082a5a..6333376 100644
--- a/nonrtric/helm/nonrtricgateway/values.yaml
+++ b/nonrtric/helm/nonrtricgateway/values.yaml
@@ -23,7 +23,7 @@
image:
registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: nonrtric-gateway
- tag: 1.0.0
+ tag: 1.1.0
service:
httpName: http
internalPort1: 9090
diff --git a/nonrtric/helm/policymanagementservice/values.yaml b/nonrtric/helm/policymanagementservice/values.yaml
index 99700ba..b0e21c8 100644
--- a/nonrtric/helm/policymanagementservice/values.yaml
+++ b/nonrtric/helm/policymanagementservice/values.yaml
@@ -23,7 +23,7 @@
image:
registry: "nexus3.o-ran-sc.org:10004/o-ran-sc"
name: nonrtric-policy-agent
- tag: 2.2.1
+ tag: 2.3.0
service:
allowHttp: true
httpName: http
diff --git a/nonrtric/helm/rappcatalogueservice/values.yaml b/nonrtric/helm/rappcatalogueservice/values.yaml
index 34af14d..507ed55 100644
--- a/nonrtric/helm/rappcatalogueservice/values.yaml
+++ b/nonrtric/helm/rappcatalogueservice/values.yaml
@@ -21,17 +21,17 @@
rappcatalogueservice:
imagePullPolicy: IfNotPresent
image:
- registry: 'nexus3.o-ran-sc.org:10002/o-ran-sc'
+ registry: 'nexus3.o-ran-sc.org:10004/o-ran-sc'
name: nonrtric-r-app-catalogue
- tag: 1.0.0
+ tag: 1.1.0
service:
allowHttp: true
httpName: http
internalPort1: 9080
- targetPort1: 8080
+ targetPort1: 8680
httpsName: https
internalPort2: 9081
- targetPort2: 8433
+ targetPort2: 8633
liveness:
initialDelaySeconds: 20
periodSeconds: 10
diff --git a/nonrtric/data/run_in_k8s/populate_enrichment_data.sh b/nonrtric/data/run_in_k8s/populate_information_data.sh
similarity index 67%
rename from nonrtric/data/run_in_k8s/populate_enrichment_data.sh
rename to nonrtric/data/run_in_k8s/populate_information_data.sh
index 14edb81..71bd916 100755
--- a/nonrtric/data/run_in_k8s/populate_enrichment_data.sh
+++ b/nonrtric/data/run_in_k8s/populate_information_data.sh
@@ -17,66 +17,66 @@
# ============LICENSE_END=================================================
#
-# This script will generate some dummy enrichment data in the running system.
+# This script will generate some dummy information data in the running system.
# It will create:
-# one EiProducer in ECS
-# one EiType in ECS
-# one EiJob in ECS
+# one EiProducer in ICS
+# one EiType in ICS
+# one EiJob in ICS
-ecs_host="enrichmentservice"
-ecs_port="9082"
+ics_host="informationservice"
+ics_port="9082"
httpx=http
-echo "ECS status:"
-curl -skw " %{http_code}" $httpx://$ecs_host:$ecs_port/status
+echo "ICS status:"
+curl -skw " %{http_code}" $httpx://$ics_host:$ics_port/status
echo -e "\n"
# Create EiType
echo "Create EiType:"
-curl -X PUT -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-producer/v1/info-types/type1 -H accept:application/json -H Content-Type:application/json --data-binary @testdata/ECS/EiType.json
+curl -X PUT -skw %{http_code} $httpx://$ics_host:$ics_port/data-producer/v1/info-types/type1 -H accept:application/json -H Content-Type:application/json --data-binary @testdata/ICS/EiType.json
echo -e "\n"
# Get EiTypes
echo "Get EiTypes:"
-curl -X GET -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-producer/v1/info-types -H Content-Type:application/json
+curl -X GET -skw %{http_code} $httpx://$ics_host:$ics_port/data-producer/v1/info-types -H Content-Type:application/json
echo -e "\n"
# Get Individual EiType
echo "Get Individual EiType:"
-curl -X GET -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-producer/v1/info-types/type1 -H Content-Type:application/json
+curl -X GET -skw %{http_code} $httpx://$ics_host:$ics_port/data-producer/v1/info-types/type1 -H Content-Type:application/json
echo -e "\n"
# Create EiProducer
echo "Create EiProducer:"
-curl -X PUT -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-producer/v1/info-producers/1 -H Content-Type:application/json --data-binary @testdata/ECS/EiProducer.json
+curl -X PUT -skw %{http_code} $httpx://$ics_host:$ics_port/data-producer/v1/info-producers/1 -H Content-Type:application/json --data-binary @testdata/ICS/EiProducer.json
echo -e "\n"
# Get EiProducers
echo "Get EiProducers:"
-curl -X GET -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-producer/v1/info-producers -H Content-Type:application/json
+curl -X GET -skw %{http_code} $httpx://$ics_host:$ics_port/data-producer/v1/info-producers -H Content-Type:application/json
echo -e "\n"
# Get Individual EiProducer
echo "Get Individual EiProducer:"
-curl -X GET -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-producer/v1/info-producers/1 -H Content-Type:application/json
+curl -X GET -skw %{http_code} $httpx://$ics_host:$ics_port/data-producer/v1/info-producers/1 -H Content-Type:application/json
echo -e "\n"
# Get Individual EiProducer Status
echo "Get Individual EiProducer:"
-curl -X GET -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-producer/v1/info-producers/1/status -H Content-Type:application/json
+curl -X GET -skw %{http_code} $httpx://$ics_host:$ics_port/data-producer/v1/info-producers/1/status -H Content-Type:application/json
echo -e "\n"
# Create EiJob
echo "Create EiJob Of A Certain Type type1:"
-curl -X PUT -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-consumer/v1/info-jobs/job1 -H Content-Type:application/json --data-binary @testdata/ECS/EiJob.json
+curl -X PUT -skw %{http_code} $httpx://$ics_host:$ics_port/data-consumer/v1/info-jobs/job1 -H Content-Type:application/json --data-binary @testdata/ICS/EiJob.json
echo -e "\n"
# Get EiJobs
echo "Get EiJobs:"
-curl -X GET -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-consumer/v1/info-jobs -H Content-Type:application/json
+curl -X GET -skw %{http_code} $httpx://$ics_host:$ics_port/data-consumer/v1/info-jobs -H Content-Type:application/json
echo -e "\n"
# Get Individual EiJob:
echo "Get Individual EiJob:"
-curl -X GET -skw %{http_code} $httpx://$ecs_host:$ecs_port/data-consumer/v1/info-jobs/job1 -H Content-Type:application/json
+curl -X GET -skw %{http_code} $httpx://$ics_host:$ics_port/data-consumer/v1/info-jobs/job1 -H Content-Type:application/json
echo -e "\n"
\ No newline at end of file